==> app-roku-v1.2.0.zip: locale/pt_BR/translations.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US" sourcelanguage="pt_BR">
<defaultcodec>UTF-8</defaultcodec>
<context>
  <name>default</name>
  <message>
    <source>Usuário</source>
    <translation>Usuário</translation>
  </message>
  <message>
    <source>Senha</source>
    <translation>Senha</translation>
  </message>
  <message>
    <source>Pressione Voltar para acessar o menu</source>
    <translation>Pressione Voltar para acessar o menu</translation>
  </message>
  <message>
    <source>Todos os canais</source>
    <translation>Todos os canais</translation>
  </message>
  <message>
    <source>Canais</source>
    <translation>Canais</translation>
  </message>
  <message>
    <source>Perfil</source>
    <translation>Perfil</translation>
  </message>
  <message>
    <source>Filmes e Séries</source>
    <translation>Filmes e Séries</translation>
  </message>
  <message>
    <source>Sair da aplicação</source>
    <translation>Sair da aplicação</translation>
  </message>
  <message>
    <source>Deseja sair da aplicação?</source>
    <translation>Deseja sair da aplicação?</translation>
  </message>
  <message>
    <source>Sair</source>
    <translation>Sair</translation>
  </message>
  <message>
    <source>Cancelar</source>
    <translation>Cancelar</translation>
  </message>
  <message>
    <source>A seguir</source>
    <translation>A seguir</translation>
  </message>
  <message>
    <source>Agora</source>
    <translation>Agora</translation>
  </message>
  <message>
    <source>Senha Inválida!</source>
    <translation>Senha Inválida!</translation>
  </message>
  <message>
    <source>Erro ao carregar conteúdo</source>
    <translation>Erro ao carregar conteúdo</translation>
  </message>
  <message>
    <source>Não foi possível carregar, tente novamente mais tarde.</source>
    <translation>Não foi possível carregar, tente novamente mais tarde.</translation>
  </message>
  <message>
    <source>Logout</source>
    <translation>Logout</translation>
  </message>
  <message>
    <source>Bem vindo</source>
    <translation>Bem vindo</translation>
  </message>
  <message>
    <source>Selecione o domínio</source>
    <translation>Selecione o domínio</translation>
  </message>
  <message>
    <source>Você deve selelecionar um provedor antes de continuar</source>
    <translation>Você deve selelecionar um provedor antes de continuar</translation>
  </message>
  <message>
    <source>Pesquise pelo seu provedor e o selecione para prosseguir.</source>
    <translation>Pesquise pelo seu provedor e o selecione para prosseguir.</translation>
  </message>
  <message>
    <source>Digite seu usuário</source>
    <translation>Digite seu usuário</translation>
  </message>
  <message>
    <source>Digite sua senha</source>
    <translation>Digite sua senha</translation>
  </message>
  <message>
    <source>Confirmação de e-mail</source>
    <translation>Confirmação de e-mail</translation>
  </message>
  <message>
    <source>Para acessar o novo conteúdo de filmes, por favor, insira seu e-mail e confirme através do link enviado.</source>
    <translation>Para acessar o novo conteúdo de filmes, por favor, insira seu e-mail e confirme através do link enviado.</translation>
  </message>
  <message>
    <source>Enviar e-mai</source>
    <translation>Enviar e-mai</translation>
  </message>
  <message>
    <source>Aguarde</source>
    <translation>Aguarde</translation>
  </message>
  <message>
    <source>Não foi possível carregar os conteúdos, tente novamente mais tarde.</source>
    <translation>Não foi possível carregar os conteúdos, tente novamente mais tarde.</translation>
  </message>
  <message>
    <source>Tentar novamente</source>
    <translation>Tentar novamente</translation>
  </message>
  <message>
    <source>Assistir</source>
    <translation>Assistir</translation>
  </message>
  <message>
    <source>Duração</source>
    <translation>Duração</translation>
  </message>
  <message>
    <source>Temporada</source>
    <translation>Temporada</translation>
  </message>
  <message>
    <source>Bom filme!</source>
    <translation>Bom filme!</translation>
  </message>
  <message>
    <source>A compra da mídia</source>
    <translation>A compra da mídia</translation>
  </message>
  <message>
    <source>foi concluida com sucesso! Aguarde alguns instantes.</source>
    <translation>foi concluida com sucesso! Aguarde alguns instantes.</translation>
  </message>
  <message>
    <source>Não foi possível efetuar a compra</source>
    <translation>Não foi possível efetuar a compra</translation>
  </message>
  <message>
    <source>não foi concluida!</source>
    <translation>não foi concluida!</translation>
  </message>
  <message>
    <source>Detalhes</source>
    <translation>Detalhes</translation>
  </message>
  <message>
    <source>Pesquisar</source>
    <translation>Pesquisar</translation>
  </message>
  <message>
    <source>Voltar</source>
    <translation>Voltar</translation>
  </message>
  <message>
    <source>Entrar</source>
    <translation>Entrar</translation>
  </message>
  <message>
    <source>Selecione seu provedor de internet</source>
    <translation>Selecione seu provedor de internet</translation>
  </message>
  <message>
    <source>Próximo</source>
    <translation>Próximo</translation>
  </message>
  <message>
    <source>Usuário autenticado com sucesso!</source>
    <translation>Usuário autenticado com sucesso!</translation>
  </message>
  <message>
    <source>Usuário bloqueado.</source>
    <translation>Usuário bloqueado.</translation>
  </message>
  <message>
    <source>Máximo de sessões atingidas.</source>
    <translation>Máximo de sessões atingidas.</translation>
  </message>
  <message>
    <source>Credenciais de acesso inválidas.</source>
    <translation>Credenciais de acesso inválidas.</translation>
  </message>
  <message>
    <source>Erro inesperado, entre em contato com seu provedor de internet.</source>
    <translation>Erro inesperado, entre em contato com seu provedor de internet.</translation>
  </message>
</context>
</TS>

==> app-roku-v1.3.0.zip: locale/pt_BR/translations.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US" sourcelanguage="pt_BR">
<defaultcodec>UTF-8</defaultcodec>
<context>
  <name>default</name>
  <message>
    <source>Usuário</source>
    <translation>Usuário</translation>
  </message>
  <message>
    <source>Senha</source>
    <translation>Senha</translation>
  </message>
  <message>
    <source>Pressione Voltar para acessar o menu</source>
    <translation>Pressione Voltar para acessar o menu</translation>
  </message>
  <message>
    <source>Todos os canais</source>
    <translation>Todos os canais</translation>
  </message>
  <message>
    <source>Canais</source>
    <translation>Canais</translation>
  </message>
  <message>
    <source>Perfil</source>
    <translation>Perfil</translation>
  </message>
  <message>
    <source>Filmes e Séries</source>
    <translation>Filmes e Séries</translation>
  </message>
  <message>
    <source>Sair da aplicação</source>
    <translation>Sair da aplicação</translation>
  </message>
  <message>
    <source>Deseja sair da aplicação?</source>
    <translation>Deseja sair da aplicação?</translation>
  </message>
  <message>
    <source>Sair</source>
    <translation>Sair</translation>
  </message>
  <message>
    <source>Cancelar</source>
    <translation>Cancelar</translation>
  </message>
  <message>
    <source>A seguir</source>
    <translation>A seguir</translation>
  </message>
  <message>
    <source>Agora</source>
    <translation>Agora</translation>
  </message>
  <message>
    <source>Senha Inválida!</source>
    <translation>Senha Inválida!</translation>
  </message>
  <message>
    <source>Erro ao carregar conteúdo</source>
    <translation>Erro ao carregar conteúdo</translation>
  </message>
  <message>
    <source>Não foi possível carregar, tente novamente mais tarde.</source>
    <translation>Não foi possível carregar, tente novamente mais tarde.</translation>
  </message>
  <message>
    <source>Logout</source>
    <translation>Logout</translation>
  </message>
  <message>
    <source>Bem vindo</source>
    <translation>Bem vindo</translation>
  </message>
  <message>
    <source>Selecione o domínio</source>
    <translation>Selecione o domínio</translation>
  </message>
  <message>
    <source>Você deve selelecionar um provedor antes de continuar</source>
    <translation>Você deve selelecionar um provedor antes de continuar</translation>
  </message>
  <message>
    <source>Pesquise pelo seu provedor e o selecione para prosseguir.</source>
    <translation>Pesquise pelo seu provedor e o selecione para prosseguir.</translation>
  </message>
  <message>
    <source>Digite seu usuário</source>
    <translation>Digite seu usuário</translation>
  </message>
  <message>
    <source>Digite sua senha</source>
    <translation>Digite sua senha</translation>
  </message>
  <message>
    <source>Confirmação de e-mail</source>
    <translation>Confirmação de e-mail</translation>
  </message>
  <message>
    <source>Para acessar o novo conteúdo de filmes, por favor, insira seu e-mail e confirme através do link enviado.</source>
    <translation>Para acessar o novo conteúdo de filmes, por favor, insira seu e-mail e confirme através do link enviado.</translation>
  </message>
  <message>
    <source>Enviar e-mai</source>
    <translation>Enviar e-mai</translation>
  </message>
  <message>
    <source>Aguarde</source>
    <translation>Aguarde</translation>
  </message>
  <message>
    <source>Não foi possível carregar os conteúdos, tente novamente mais tarde.</source>
    <translation>Não foi possível carregar os conteúdos, tente novamente mais tarde.</translation>
  </message>
  <message>
    <source>Tentar novamente</source>
    <translation>Tentar novamente</translation>
  </message>
  <message>
    <source>Assistir</source>
    <translation>Assistir</translation>
  </message>
  <message>
    <source>Duração</source>
    <translation>Duração</translation>
  </message>
  <message>
    <source>Temporada</source>
    <translation>Temporada</translation>
  </message>
  <message>
    <source>Bom filme!</source>
    <translation>Bom filme!</translation>
  </message>
  <message>
    <source>A compra da mídia</source>
    <translation>A compra da mídia</translation>
  </message>
  <message>
    <source>foi concluida com sucesso! Aguarde alguns instantes.</source>
    <translation>foi concluida com sucesso! Aguarde alguns instantes.</translation>
  </message>
  <message>
    <source>Não foi possível efetuar a compra</source>
    <translation>Não foi possível efetuar a compra</translation>
  </message>
  <message>
    <source>não foi concluida!</source>
    <translation>não foi concluida!</translation>
  </message>
  <message>
    <source>Detalhes</source>
    <translation>Detalhes</translation>
  </message>
  <message>
    <source>Pesquisar</source>
    <translation>Pesquisar</translation>
  </message>
  <message>
    <source>Voltar</source>
    <translation>Voltar</translation>
  </message>
  <message>
    <source>Entrar</source>
    <translation>Entrar</translation>
  </message>
  <message>
    <source>Selecione seu provedor de internet</source>
    <translation>Selecione seu provedor de internet</translation>
  </message>
  <message>
    <source>Próximo</source>
    <translation>Próximo</translation>
  </message>
  <message>
    <source>Usuário autenticado com sucesso!</source>
    <translation>Usuário autenticado com sucesso!</translation>
  </message>
  <message>
    <source>Usuário bloqueado.</source>
    <translation>Usuário bloqueado.</translation>
  </message>
  <message>
    <source>Máximo de sessões atingidas.</source>
    <translation>Máximo de sessões atingidas.</translation>
  </message>
  <message>
    <source>Credenciais de acesso inválidas.</source>
    <translation>Credenciais de acesso inválidas.</translation>
  </message>
  <message>
    <source>Erro inesperado, entre em contato com seu provedor de internet.</source>
    <translation>Erro inesperado, entre em contato com seu provedor de internet.</translation>
  </message>
  <message>
    <source>Senha alterada com sucesso.</source>
    <translation>Senha alterada com sucesso.</translation>
  </message>
    <message>
    <source>As senhas não conferem</source>
    <translation>As senhas não conferem</translation>
  </message>
  <message>
  <source>Erro</source>
  <translation>Erro</translation>
</message>
<message>
<source>Sucesso</source>
<translation>Sucesso</translation>
</message>
<message>
<source>Alterar senha para conteúdo adulto</source>
<translation>Alterar senha para conteúdo adulto</translation>
</message>
<message>
<source>Conteudo adulto</source>
<translation>Conteúdo adulto</translation>
</message>
<message>
<source>Confirme a senha</source>
<translation>Confirme a senha</translation>
</message>
<message>
<source>Continuar</source>
<translation>Continuar</translation>
</message>
<message>
<source>Cancelar</source>
<translation>Cancelar</translation>
</message>
</context>
</TS>
